@@ -42,7 +42,8 @@
 
 #define SCALED_PREVIEW_MAX_SIDE 400
 
-static const int ActiveSelection = 100000;
+static constexpr int ActiveSelection = 100000;
+static constexpr int PageSizeWiggleRoom = 2; // in mm
 
 namespace KSaneIface
 {
@@ -84,10 +85,13 @@ KSaneWidgetPrivate::KSaneWidgetPrivate(KSaneWidget *parent):
     m_previewHeight = 0;
 
     m_sizeCodes = {
-        QPageSize::A3,
         QPageSize::A4,
         QPageSize::A5,
         QPageSize::A6,
+        QPageSize::Letter,
+        QPageSize::Legal,
+        QPageSize::Tabloid,
+        QPageSize::A3,
         QPageSize::B3,
         QPageSize::B4,
         QPageSize::B5,
@@ -98,9 +102,6 @@ KSaneWidgetPrivate::KSaneWidgetPrivate(KSaneWidget *parent):
         QPageSize::Executive,
         QPageSize::Folio,
         QPageSize::Ledger,
-        QPageSize::Legal,
-        QPageSize::Letter,
-        QPageSize::Tabloid,
         QPageSize::JisB3,
         QPageSize::JisB4,
         QPageSize::JisB5,
@@ -393,14 +394,18 @@ void KSaneWidgetPrivate::createOptInterface()
     m_basicScrollA->setWidget(m_basicOptsTab);
 
     QVBoxLayout *basic_layout = new QVBoxLayout(m_basicOptsTab);
-    KSaneOption *option;
+    KSaneOption *option = getOption(QStringLiteral(SANE_NAME_SCAN_SOURCE));
     // Scan Source
-    if ((option = getOption(QStringLiteral(SANE_NAME_SCAN_SOURCE))) != nullptr) {
+    if (option != nullptr) {
         m_optSource = option;
         option->createWidget(m_basicOptsTab);
         basic_layout->addWidget(option->widget());
         connect(m_optSource, SIGNAL(valueChanged()), this, SLOT(checkInvert()), Qt::QueuedConnection);
+        connect(m_optSource, &KSaneOption::valueChanged, this, [this]() {
+            m_previewViewer->setMultiselectionEnabled(!scanSourceADF());
+        });
     }
+
     // film-type (note: No translation)
     if ((option = getOption(QStringLiteral("film-type"))) != nullptr) {
         m_optFilmType = option;
@@ -1130,6 +1135,20 @@ void KSaneWidgetPrivate::startFinalScan()
     m_scanThread->start();
 }
 
+bool KSaneWidgetPrivate::scanSourceADF()
+{
+    if (!m_optSource) {
+        return false;
+    }
+
+    QString source;
+    m_optSource->getValue(source);
+
+    return source.contains(QStringLiteral("Automatic Document Feeder")) ||
+    source.contains(QStringLiteral("ADF")) ||
+    source.contains(QStringLiteral("Duplex"));
+}
+
 void KSaneWidgetPrivate::oneFinalScanDone()
 {
     m_updProgressTmr.stop();
@@ -1159,23 +1178,12 @@ void KSaneWidgetPrivate::oneFinalScanDone()
                            (int)getImgFormat(params));
 
         // now check if we should have automatic ADF batch scanning
-        if (m_optSource) {
-            QString source;
-            m_optSource->getValue(source);
-
-            if (source.contains(QStringLiteral("Automatic Document Feeder")) ||
-                source.contains(QStringLiteral("ADF")) ||
-                source.contains(QStringLiteral("Duplex"))) {
-                // in batch mode only one area can be scanned per page
-                //qCDebug(KSANE_LOG) << "source == " << source;
-                if (!m_cancelMultiScan) {
-                    m_updProgressTmr.start();
-                    m_scanThread->start();
-                    m_cancelMultiScan = false;
-                    return;
-                }
-
-            }
+        if (scanSourceADF() && !m_cancelMultiScan) {
+            // in batch mode only one area can be scanned per page
+            m_updProgressTmr.start();
+            m_scanThread->start();
+            m_cancelMultiScan = false;
+            return;
         }
 
         // Check if we have a "wait for button" batch scanning
@@ -1444,10 +1452,10 @@ void KSaneWidgetPrivate::setPossibleScanSizes()
     // Add portrait page sizes
     for (int sizeCode: qAsConst(m_sizeCodes)) {
         QSizeF size = QPageSize::size((QPageSize::PageSizeId)sizeCode, QPageSize::Millimeter);
-        if (mmToDispUnit(size.width()) > widthInDispUnit) {
+        if (mmToDispUnit(size.width() - PageSizeWiggleRoom) > widthInDispUnit) {
             continue;
         }
-        if (mmToDispUnit(size.height()) > heightInDispUnit) {
+        if (mmToDispUnit(size.height() - PageSizeWiggleRoom) > heightInDispUnit) {
             continue;
         }
         m_scanareaPapersize->addItem(QPageSize::name((QPageSize::PageSizeId)sizeCode), size);
@@ -1457,10 +1465,10 @@ void KSaneWidgetPrivate::setPossibleScanSizes()
     for (int sizeCode: qAsConst(m_sizeCodes)) {
         QSizeF size = QPageSize::size((QPageSize::PageSizeId)sizeCode, QPageSize::Millimeter);
         size.transpose();
-        if (mmToDispUnit(size.width()) > widthInDispUnit) {
+        if (mmToDispUnit(size.width() - PageSizeWiggleRoom) > widthInDispUnit) {
             continue;
         }
-        if (mmToDispUnit(size.height()) > heightInDispUnit) {
+        if (mmToDispUnit(size.height() - PageSizeWiggleRoom) > heightInDispUnit) {
             continue;
         }
         QString name = QPageSize::name((QPageSize::PageSizeId)sizeCode) +
